import 'package:flutter/material.dart';
import 'module_route.dart';

class Modules {
  static final Modules _singleton = Modules._internal();
  final List<ModuleRoute> _modules = [];

  factory Modules() {
    return _singleton;
  }

  Modules._internal();

  void addModules(List<ModuleRoute> modules) {
    _modules.addAll(modules);
  }

  List<ModuleRoute> getModules() => _modules;

  static T? arguments<T extends Argument>(RouteSettings settings, String path,
      T Function(Map<String, dynamic> data) fromMap) {
    if (settings.name != null) {
      Uri uri = Uri.parse(settings.name ?? '');
      if (settings.arguments != null) {
        return settings.arguments as T;
      }
      if (uri.pathSegments.isNotEmpty || uri.queryParameters.isNotEmpty) {
        List<String> segments = [...uri.pathSegments];
        if (segments.length % 2 == 1) {
          segments.removeAt(0);
        }
        Map<String, String> result = {};
        for (int a = 0; a < segments.length; a = a + 2) {
          result[segments[a]] = segments[a + 1];
        }
        result = {...result, ...uri.queryParameters};
        T arg1 = fromMap(result);
        return arg1;
      }
    }
    return null;
  }
}

abstract class Argument {
  Map<String, dynamic> toMap();
  factory Argument.fromMap(Map<String, dynamic> map) =>
      throw UnimplementedError();
}
